@@ -5,13 +5,13 @@ class PowerShell(WindowShellBase):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
-    def launch(self):
+    def start(self):
         pass
 
     def __enter__(self):
         pass
 
-    def __exit__(self):
+    def __exit__(self, *args):
         pass
 
     def setCurrent(self):
